pub struct CourierQuestInstance {
pub kind: CourierQuest,
pub spot: Option<Vec2<i32>>,
pub source_site: Option<SiteId>,
pub source_actor: Actor,
pub target_actor: Actor,
pub target_site: Option<SiteId>,
pub messenger: Actor,
pub distance: NonZeroU32,
}Expand description
Contains a completable courier quest.
Fields
kind: CourierQuestspot: Option<Vec2<i32>>source_site: Option<SiteId>The source site may or may not be useful in all situations, but we do
want to keep it available in case we need to have dialogue that says
something like “Wow, you came all the way from
source_actor: Actortarget_actor: ActorThis is source_actor for fetch quests.
target_site: Option<SiteId>Target actor’s site, if available.
messenger: ActorUsually this is the player.
distance: NonZeroU32The distance to be traversed, calculated once at quest start.
Implementations
Sourceimpl CourierQuestInstance
This file only contains an implementation for quest interactions. Make sure
to look for other implementations.
impl CourierQuestInstance
This file only contains an implementation for quest interactions. Make sure to look for other implementations.
Sourcepub fn get_required_items(self) -> Result<Vec<(Arc<ItemDef>, f32)>, Error>
pub fn get_required_items(self) -> Result<Vec<(Arc<ItemDef>, f32)>, Error>
Returns a list of all items that are required for completing this courier quest.
Sourcepub fn get_reward(self) -> f32
pub fn get_reward(self) -> f32
Returns the number of coins that the quest arbiter must pay upon courier quest completion. Note that in some cases the arbiter is not the person that paid the quest deposit.
Sourcepub fn get_spot_map_label(self, npc_name: &str) -> Content
pub fn get_spot_map_label(self, npc_name: &str) -> Content
Retrieves the i18n content that will be shown on the map when hovering over the courier quest’s map marker.
Sourcepub fn lacks_items(self) -> Content
pub fn lacks_items(self) -> Content
“You don’t have enough items on you to complete this quest.”
Sourcepub fn what_items_needed(
self,
is_target_npc: bool,
npc_name: &str,
) -> (Content, Content)
pub fn what_items_needed( self, is_target_npc: bool, npc_name: &str, ) -> (Content, Content)
Assembles the dialogue question and response when asking what items are needed in order to complete an active courier quest.
“What am I supposed to be getting for you/target again?” “You need X, Y, and Z to complete this courier quest.”
Sourcepub fn get_spot_name(self) -> Content
pub fn get_spot_name(self) -> Content
Retrieves the i18n content for the name of the spot, or a generic response if the courier quest variant does not need a spot.
Sourcepub fn get_start_dialogue(
self,
tgt_npc_name_str: &str,
tgt_site_name: &str,
) -> (Content, Content)
pub fn get_start_dialogue( self, tgt_npc_name_str: &str, tgt_site_name: &str, ) -> (Content, Content)
Returns the i18n content for the initial courier quest statement/preamble that an NPC will say, as well as the subsequent yes/no question that they ask that allows starting the quest.
Note that not every quest uses the target npc name or the target site name.
Sourcepub fn get_dialogue_where_target(
self,
npc_name: &str,
at: Vec2<f32>,
target: Actor,
) -> (Content, Marker, Content)
pub fn get_dialogue_where_target( self, npc_name: &str, at: Vec2<f32>, target: Actor, ) -> (Content, Marker, Content)
“Where is my target again?” Map gets marked with a marker, and the NPC responds with their location.
Sourcepub fn get_courier_claim_dialogue(self) -> (Content, Content)
pub fn get_courier_claim_dialogue(self) -> (Content, Content)
Returns the dialogue question and response that an entity will use when the courier quest’s messenger is speaking to the quest target and is attempting to finish the quest (claim the reward).